summaryrefslogtreecommitdiffstats
path: root/Source
diff options
context:
space:
mode:
authorWill Schroeder <will.schroeder@kitware.com>2000-11-09 15:41:37 (GMT)
committerWill Schroeder <will.schroeder@kitware.com>2000-11-09 15:41:37 (GMT)
commit65a28c7705657c81e77b6a9bfbfedacd1a80d081 (patch)
tree68d23cc6291a9acf5e5f4d88271f18857cf12f72 /Source
parent541dc47395132baee8b8b9349d496b41194185a4 (diff)
downloadCMake-65a28c7705657c81e77b6a9bfbfedacd1a80d081.zip
CMake-65a28c7705657c81e77b6a9bfbfedacd1a80d081.tar.gz
CMake-65a28c7705657c81e77b6a9bfbfedacd1a80d081.tar.bz2
ENH:Changed CMAKE_SOURCE_ROOT to CMAKE_SOURCE_DIR
Diffstat (limited to 'Source')
-rw-r--r--Source/cmCollectFlags.cxx6
-rw-r--r--Source/cmCollectFlags.h2
-rw-r--r--Source/cmWindowsConfigure.cxx6
3 files changed, 7 insertions, 7 deletions
diff --git a/Source/cmCollectFlags.h b/Source/cmCollectFlags.h
index 28448b1..d37afb0 100644
--- a/Source/cmCollectFlags.h
+++ b/Source/cmCollectFlags.h
@@ -51,7 +51,7 @@ public:
/**
* Expance varibles for home and binary root in the collected flags.
- * CMAKE_BINARY_DIR and CMAKE_SOURCE_ROOT are replaced with
+ * CMAKE_BINARY_DIR and CMAKE_SOURCE_DIR are replaced with
* makefile->GetOutputHomeDirectory() and
* makefile->GetHomeDirectory()
*/
diff --git a/Source/cmWindowsConfigure.cxx b/Source/cmWindowsConfigure.cxx
index 0014265..db9275f 100644
--- a/Source/cmWindowsConfigure.cxx
+++ b/Source/cmWindowsConfigure.cxx
@@ -34,15 +34,15 @@ bool cmWindowsConfigure::Configure(const char* file)
toFile += toFileName;
cmSystemTools::ReplaceString(toFile, "${CMAKE_BINARY_DIR}",
m_WhereBuild.c_str() );
- cmSystemTools::ReplaceString(toFile, "${CMAKE_SOURCE_ROOT}",
+ cmSystemTools::ReplaceString(toFile, "${CMAKE_SOURCE_DIR}",
m_WhereSource.c_str() );
cmSystemTools::ReplaceString(fromFile, "${CMAKE_BINARY_DIR}",
m_WhereBuild.c_str() );
- cmSystemTools::ReplaceString(fromFile, "${CMAKE_SOURCE_ROOT}",
+ cmSystemTools::ReplaceString(fromFile, "${CMAKE_SOURCE_DIR}",
m_WhereSource.c_str() );
cmSystemTools::ReplaceString(destDir, "${CMAKE_BINARY_DIR}",
m_WhereBuild.c_str() );
- cmSystemTools::ReplaceString(destDir, "${CMAKE_SOURCE_ROOT}",
+ cmSystemTools::ReplaceString(destDir, "${CMAKE_SOURCE_DIR}",
m_WhereSource.c_str() );
}
}
diff --git a/Source/cmCollectFlags.cxx b/Source/cmCollectFlags.cxx
index 6e7e33c..855dd20 100644
--- a/Source/cmCollectFlags.cxx
+++ b/Source/cmCollectFlags.cxx
@@ -110,7 +110,7 @@ void cmCollectFlags::ParseDirectory(const char* dir)
}
// expance CMAKE_BINARY_DIR and CMAKE_SOURCE_ROOT in the
// include and library directories.
void cmCollectFlags::ExpandVaribles(cmMakefile* makefile)
@@ -124,7 +124,7 @@ void cmCollectFlags::ExpandVaribles(cmMakefile* makefile)
{
cmSystemTools::ReplaceString(*j, "${CMAKE_BINARY_DIR}",
makefile->GetOutputHomeDirectory() );
- cmSystemTools::ReplaceString(*j, "${CMAKE_SOURCE_ROOT}",
+ cmSystemTools::ReplaceString(*j, "${CMAKE_SOURCE_DIR}",
makefile->GetHomeDirectory() );
}
begin = m_LinkDirectories.begin();
@@ -133,7 +133,7 @@ void cmCollectFlags::ExpandVaribles(cmMakefile* makefile)
{
cmSystemTools::ReplaceString(*j, "${CMAKE_BINARY_DIR}",
makefile->GetOutputHomeDirectory() );
- cmSystemTools::ReplaceString(*j, "${CMAKE_SOURCE_ROOT}",
+ cmSystemTools::ReplaceString(*j, "${CMAKE_SOURCE_DIR}",
makefile->GetHomeDirectory() );
}
}
@@ -110,7 +110,7 @@ void cmCollectFlags::ParseDirectory(const char* dir)
}
-// expance CMAKE_BINARY_DIR and CMAKE_SOURCE_ROOT in the
+// expance CMAKE_BINARY_DIR and CMAKE_SOURCE_DIR in the
// include and library directories.
void cmCollectFlags::ExpandVaribles(cmMakefile* makefile)